Fedimg — Fedimg 1.3.0 documentation

# Fedimg

Fedimg is a Python-powered service that is built to make Fedora Cloud and Atomic Host images available on popular cloud providers, such as Amazon Web Services.

Salient features:

- Performs automatic uploads, triggered by activity on the Fedmsg bus.
- Register images as Hardware Virtual Machine (HVM).
- Emits fedmsg messages, providing the upload status and the Amazon Machine Image (AMI) info.
- Packaged for EPEL7, Fedora as well as PyPI.

## License

Fedimg is licensed under the AGPL, version 3 or later.

Contents:

- Configuration
  - General options
  - AWS options
- FedimgConsumer
- Development Guide
- Contribution Guidelines
  - Communicating with other contributors
  - Submitting changes
- Testing
  - Running the tests

- Release Notes

## Community

Fedimg is maintained by the Fedora Project and it’s source code and issue tracker are on Github. Join the mailing list or/and the IRC channel on FreeNode, `#fedora-cloud` for discussion on Fedimg.